==> nextcloud-app-calendar-1.5.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/tr.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Takvim",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Uzak sunucu takvim erişimine izin vermedi (HTTP {%s} hatası)",
    "Error connecting to remote server" : "Uzak sunucuya bağlanılırken bir sorun çıktı",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Uzak sunucu üzerindeki kaynak istenirken bir sorun çıktı. Bu sorun bir sertifika uyuşmazlığından kaynaklanıyor olabilir",
    "Error requesting resource on remote server" : "Uzak sunucu üzerindeki kaynak istenirken bir sorun çıktı",
    "%s has published the calendar \"%s\"" : "%s, \"%s\" takvimini yayınladı",
    "Individual" : "Birey",
    "Group" : "Grup",
    "Resource" : "Kaynak",
    "Room" : "Oda",
    "Unknown" : "Bilinmiyor",
    "Required" : "Zorunlu",
    "Optional" : "İsteğe Bağlı",
    "Does not attend" : "Katılmıyor",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Bilinmeyen bir saat dilimindesiniz ({tz}), UTC dilimine dönülüyor",
    "Please create a calendar first." : "Lütfen önce bir takvim oluşturun.",
    "New event" : "Yeni etkinlik",
    "CalDAV address for clients" : "İstemciler için CalDAV adresi",
    "Error saving WebCal-calendar" : "WebCal takvimi kaydedilirken bir sorun çıktı",
    "WebDAV address for subscriptions" : "Abonelikler için WebDAV adresi",
    "EMail has been sent." : "E-posta gönderildi.",
    "There was an issue while sending your EMail." : "E-posta gönderilirken bir sorun çıktı.",
    "group" : "grup",
    "Details" : "Ayrıntılar",
    "Attendees" : "Katılanlar",
    "Reminders" : "Anımsatıcılar",
    "Repeating" : "Yinelenme",
    "When shared show full event" : "Paylaşıldığında etkinliğin ayrıntıları görüntülensin",
    "When shared show only busy" : "Paylaşıldğında yalnız meşgul olarak görüntülensin",
    "When shared hide this event" : "Paylaşıldığında etkinlik gizlensin",
    "Confirmed" : "Onaylanmış",
    "Tentative" : "Olabilir",
    "Cancelled" : "İptal edilmiş",
    "Please add a title!" : "Lütfen bir başlık yazın!",
    "Please select a calendar!" : "Lütfen bir takvim seçin!",
    "Global" : "Genel",
    "None" : "Hiçbiri",
    "Every day" : "Her gün",
    "Every week" : "Her hafta",
    "Every month" : "Her ay",
    "Every year" : "Her yıl",
    "never" : "asla",
    "after" : "şundan sonra",
    "How about getting started by importing some calendars?" : "Bazı takvimleri alarak başlamak ister misiniz?",
    "At time of event" : "Etkinlik zamanında",
    "5 minutes before" : "5 dakika önce",
    "10 minutes before" : "10 dakika önce",
    "15 minutes before" : "15 dakika önce",
    "30 minutes before" : "30 dakika önce",
    "1 hour before" : "1 saat önce",
    "2 hours before" : "2 saat önce",
    "Custom" : "Özel",
    "Audio" : "Ses",
    "E Mail" : "E-posta",
    "Pop up" : "Açılır pencere",
    "sec" : "saniye",
    "min" : "dakika",
    "hours" : "saat",
    "days" : "gün",
    "week" : "hafta",
    "before" : "şundan önce",
    "start" : "başlangıç",
    "end" : "bitiş",
    "Editing reminders of unknown type not supported." : "Bilinmeyen türdeki anımsatıcıların düzenlenmesi desteklenmiyor.",
    "Week {number} of {year}" : "{year} yılının {number}. haftası",
    "Successfully imported" : "Alındı",
    "Partially imported, 1 failure" : "Kısmen alındı, 1 başarısız",
    "Partially imported, {n} failures" : "Kısmen alındı, {n} başarısız",
    "Audio alarm" : "Sesli uyarı",
    "Pop-up" : "Açılır pencere",
    "E-Mail" : "E-posta",
    "{type} {time} before the event starts" : "Etkinlik başlamadan {time} önce {type}",
    "{type} {time} before the event ends" : "Etkinlik bitmeden {time} önce {type}",
    "{type} {time} after the event starts" : "Etkinlik başladıktan {time} sonra {type}",
    "{type} {time} after the event ends" : "Etkinlik bittikten {time} sonra {type}",
    "{type} at the event's start" : "Etkinlik başlangıcında {type}",
    "{type} at the event's end" : "Etkinlik bitiminde {type}",
    "{type} at {time}" : "{time} zamanında {type}",
    "{calendar} shared by {owner}" : "{owner} tarafından paylaşılmış {calendar}",
    "Please enter a valid WebCal-URL" : "Lütfen geçerli bir WebCal adresi yazın",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Webcal vekil sunucusunda ciddi bir sorun var. Lütfen ayrıntılı bilgi almak için yönetici ile görüşün.",
    "Title of the Event" : "Etkinlik Başlığı",
    "starts" : "başlangıç",
    "ends" : "bitiş",
    "All day Event" : "Tüm günlük etkinlik",
    "Delete" : "Sil",
    "Cancel" : "İptal",
    "More ..." : "Diğer ...",
    "Create" : "Ekle",
    "Update" : "Güncelle",
    "Close" : "Kapat",
    "Location" : "Konum",
    "Description" : "Açıklama",
    "Event status" : "Etkinlik durumu",
    "Visibility when sharing" : "Paylaşımda görünürlük",
    "Export" : "Ver",
    "%s has published the calendar %s" : "%s, %s takvimini yayınladı",
    "Hello," : "Merhaba,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Bu ileti %s tarafından {boldstart}%s{boldend} takviminin yayınlandığını bildirmek üzere gönderilmiştir.",
    "Click here to access it" : "Takvime erişmek için buraya tıklayın",
    "Cheers!" : "Görüşmek üzere",
    "We wanted to inform you that %s has published the calendar %s." : "Bu ileti %s tarafından %s takviminin yayınlandığını bildirmek üzere gönderilmiştir.",
    "Click on the link below to access it" : "Takvime eirşmek için aşağıdaki bağlantıya tıklayın",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Bir yükleme akışı hatası nedeniyle takvim asset pipeline özelliğine destek veremiyor.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Lütfen yöneticinizle görüşerek \"asset-pipeline.enabled\" ayarını devre dışı bırakmasını isteyin.",
    "Day" : "Gün",
    "Week" : "Hafta",
    "Month" : "Ay",
    "Today" : "Bugün",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Bu takvimdeki bazı etkinliklerde sorun var. Ayrıntılı bilgi almak için JS konsoluna bakın.",
    "Share Calendar" : "Takvimi Paylaş",
    "Shared" : "Paylaşıldı",
    "More" : "Diğer",
    "Edit" : "Düzenle",
    "Link" : "Bağlantı",
    "WebCal URL" : "WebCal adresi",
    "Download" : "İndir",
    "Share with users or groups" : "Kullanıcı ve gruplarla paylaş",
    "can edit" : "düzenleyebilir",
    "Share link" : "Bağlantıyı paylaş",
    "Public access" : "Herkese açık erişim",
    "Email link to person" : "Bağlantıyı e-posta ile gönder",
    "Send" : "Gönder",
    "New Calendar" : "Takvim Ekle",
    "Name" : "Ad",
    "New Subscription" : "Abonelik Ekle",
    "WebCal-URL" : "WebCal-adresi",
    "Go back" : "Geri dön",
    "Go forward" : "İleri git",
    "Edit event" : "Etkinliği düzenle",
    "Delete Event" : "Etkinliği Sil",
    "Save Event" : "Etkinliği Kaydet",
    "Time" : "Zaman",
    "Type" : "Tür",
    "Relative" : "Bağıl",
    "Absolute" : "Mutlak",
    "Repeat" : "Yineleme",
    "times every" : "kez, her",
    "Add" : "Ekle",
    "E-Mail address of attendee" : "Katılımcının e-posta adresi",
    "Please add your email address in the personal settings in order to add attendees." : "Lütfen katılımcıları eklemek için kişisel ayarlardan e-posta adresinizi ekleyin.",
    "from" : "başlangıç",
    "to" : "bitiş",
    "This event's repeating rule is not supported yet." : "Bu etkinliğin yinelenme kuralı henüz desteklenmiyor.",
    "Support for advanced rules will be added with subsequent updates." : "Gelişmiş kural desteği sonraki sürümlerde eklenecek.",
    "Reset repeating rule" : "Yinelenme kuralını sıfırla",
    "Repeat every ..." : "Yinelenme...",
    "end repeat ..." : "yinelenme sonu...",
    "times" : "kez",
    "Import Calendars" : "Takvimleri Al",
    "Import canceled" : "Alma işlemi iptal edildi",
    "Analyzing calendar" : "Takvim inceleniyor",
    "The file contains objects incompatible with the selected calendar" : "Dosyada, seçilmiş takvime uygun olmayan nesneler var",
    "New calendar" : "Takvim ekle",
    "File is empty" : "Dosya boş",
    "Import scheduled" : "Alma işlemi zamanlandı",
    "Settings" : "Ayarlar",
    "Publish URL" : "Yayın adresi",
    "Iframe to integrate" : "bütünleştirilecek Iframe",
    "Skip simple event editor" : "Basit etkinlik düzenleyici atlansın",
    "Show week numbers" : "Hafta numaraları görüntülensin",
    "Import calendar" : "Takvimi al",
    "No Calendars selected for import" : "Alınacak bir takvim seçilmemiş",
    "Primary CalDAV address" : "Birincil CalDAV adresi",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresi"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-calendar-1.5.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/tr.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Takvim",
    "%s has published the calendar \"%s\"" : "%s, \"%s\" takvimini yayınladı",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Uzak sunucu takvim erişimine izin vermedi (HTTP {%s} hatası)",
    "Error connecting to remote server" : "Uzak sunucuya bağlanılırken bir sorun çıktı",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Uzak sunucu üzerindeki kaynak istenirken bir sorun çıktı. Bu sorun bir sertifika uyuşmazlığından kaynaklanıyor olabilir",
    "Error requesting resource on remote server" : "Uzak sunucu üzerindeki kaynak istenirken bir sorun çıktı",
    "Individual" : "Birey",
    "Group" : "Grup",
    "Resource" : "Kaynak",
    "Room" : "Oda",
    "Unknown" : "Bilinmiyor",
    "Required" : "Zorunlu",
    "Optional" : "İsteğe Bağlı",
    "Does not attend" : "Katılmıyor",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Bilinmeyen bir saat dilimindesiniz ({tz}), UTC dilimine dönülüyor",
    "Please create a calendar first." : "Lütfen önce bir takvim oluşturun.",
    "New event" : "Yeni etkinlik",
    "CalDAV address for clients" : "İstemciler için CalDAV adresi",
    "Error saving WebCal-calendar" : "WebCal takvimi kaydedilirken bir sorun çıktı",
    "WebDAV address for subscriptions" : "Abonelikler için WebDAV adresi",
    "EMail has been sent." : "E-posta gönderildi.",
    "There was an issue while sending your EMail." : "E-posta gönderilirken bir sorun çıktı.",
    "group" : "grup",
    "Details" : "Ayrıntılar",
    "Attendees" : "Katılanlar",
    "Reminders" : "Anımsatıcılar",
    "Repeating" : "Yinelenme",
    "When shared show full event" : "Paylaşıldığında etkinliğin ayrıntıları görüntülensin",
    "When shared show only busy" : "Paylaşıldğında yalnız meşgul olarak görüntülensin",
    "When shared hide this event" : "Paylaşıldığında etkinlik gizlensin",
    "Confirmed" : "Onaylanmış",
    "Tentative" : "Olabilir",
    "Cancelled" : "İptal edilmiş",
    "Please add a title!" : "Lütfen bir başlık yazın!",
    "Please select a calendar!" : "Lütfen bir takvim seçin!",
    "Global" : "Genel",
    "None" : "Hiçbiri",
    "Every day" : "Her gün",
    "Every week" : "Her hafta",
    "Every month" : "Her ay",
    "Every year" : "Her yıl",
    "never" : "asla",
    "after" : "şundan sonra",
    "How about getting started by importing some calendars?" : "Bazı takvimleri alarak başlamak ister misiniz?",
    "At time of event" : "Etkinlik zamanında",
    "5 minutes before" : "5 dakika önce",
    "10 minutes before" : "10 dakika önce",
    "15 minutes before" : "15 dakika önce",
    "30 minutes before" : "30 dakika önce",
    "1 hour before" : "1 saat önce",
    "2 hours before" : "2 saat önce",
    "Custom" : "Özel",
    "Audio" : "Ses",
    "E Mail" : "E-posta",
    "Pop up" : "Açılır pencere",
    "sec" : "saniye",
    "min" : "dakika",
    "hours" : "saat",
    "days" : "gün",
    "week" : "hafta",
    "before" : "şundan önce",
    "start" : "başlangıç",
    "end" : "bitiş",
    "Editing reminders of unknown type not supported." : "Bilinmeyen türdeki anımsatıcıların düzenlenmesi desteklenmiyor.",
    "Week {number} of {year}" : "{year} yılının {number}. haftası",
    "Successfully imported" : "Alındı",
    "Partially imported, 1 failure" : "Kısmen alındı, 1 başarısız",
    "Partially imported, {n} failures" : "Kısmen alındı, {n} başarısız",
    "Audio alarm" : "Sesli uyarı",
    "Pop-up" : "Açılır pencere",
    "E-Mail" : "E-posta",
    "{type} {time} before the event starts" : "Etkinlik başlamadan {time} önce {type}",
    "{type} {time} before the event ends" : "Etkinlik bitmeden {time} önce {type}",
    "{type} {time} after the event starts" : "Etkinlik başladıktan {time} sonra {type}",
    "{type} {time} after the event ends" : "Etkinlik bittikten {time} sonra {type}",
    "{type} at the event's start" : "Etkinlik başlangıcında {type}",
    "{type} at the event's end" : "Etkinlik bitiminde {type}",
    "{type} at {time}" : "{time} zamanında {type}",
    "{calendar} shared by {owner}" : "{owner} tarafından paylaşılmış {calendar}",
    "Please enter a valid WebCal-URL" : "Lütfen geçerli bir WebCal adresi yazın",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Webcal vekil sunucusunda ciddi bir sorun var. Lütfen ayrıntılı bilgi almak için yönetici ile görüşün.",
    "Title of the Event" : "Etkinlik Başlığı",
    "starts" : "başlangıç",
    "ends" : "bitiş",
    "All day Event" : "Tüm günlük etkinlik",
    "Delete" : "Sil",
    "Cancel" : "İptal",
    "More ..." : "Diğer ...",
    "Create" : "Ekle",
    "Update" : "Güncelle",
    "Close" : "Kapat",
    "Location" : "Konum",
    "Description" : "Açıklama",
    "Event status" : "Etkinlik durumu",
    "Visibility when sharing" : "Paylaşımda görünürlük",
    "Export" : "Ver",
    "%s has published the calendar %s" : "%s, %s takvimini yayınladı",
    "Hello," : "Merhaba,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Bu ileti %s tarafından {boldstart}%s{boldend} takviminin yayınlandığını bildirmek üzere gönderilmiştir.",
    "Click here to access it" : "Takvime erişmek için buraya tıklayın",
    "Cheers!" : "Görüşmek üzere",
    "We wanted to inform you that %s has published the calendar %s." : "Bu ileti %s tarafından %s takviminin yayınlandığını bildirmek üzere gönderilmiştir.",
    "Click on the link below to access it" : "Takvime eirşmek için aşağıdaki bağlantıya tıklayın",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Bir yükleme akışı hatası nedeniyle takvim asset pipeline özelliğine destek veremiyor.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Lütfen yöneticinizle görüşerek \"asset-pipeline.enabled\" ayarını devre dışı bırakmasını isteyin.",
    "Day" : "Gün",
    "Week" : "Hafta",
    "Month" : "Ay",
    "Today" : "Bugün",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Bu takvimdeki bazı etkinliklerde sorun var. Ayrıntılı bilgi almak için JS konsoluna bakın.",
    "Share Calendar" : "Takvimi Paylaş",
    "Shared" : "Paylaşıldı",
    "More" : "Diğer",
    "Edit" : "Düzenle",
    "Link" : "Bağlantı",
    "iCal link" : "iCal bağlantı",
    "Download" : "İndir",
    "Share with users or groups" : "Kullanıcı ve gruplarla paylaş",
    "can edit" : "düzenleyebilir",
    "Share link" : "Bağlantıyı paylaş",
    "Public access" : "Herkese açık erişim",
    "Email link to person" : "Bağlantıyı e-posta ile gönder",
    "Send" : "Gönder",
    "New Calendar" : "Takvim Ekle",
    "Name" : "Ad",
    "New Subscription" : "Abonelik Ekle",
    "Go back" : "Geri dön",
    "Go forward" : "İleri git",
    "Edit event" : "Etkinliği düzenle",
    "Delete Event" : "Etkinliği Sil",
    "Save Event" : "Etkinliği Kaydet",
    "Time" : "Zaman",
    "Type" : "Tür",
    "Relative" : "Bağıl",
    "Absolute" : "Mutlak",
    "Repeat" : "Yineleme",
    "times every" : "kez, her",
    "Add" : "Ekle",
    "E-Mail address of attendee" : "Katılımcının e-posta adresi",
    "Please add your email address in the personal settings in order to add attendees." : "Lütfen katılımcıları eklemek için kişisel ayarlardan e-posta adresinizi ekleyin.",
    "from" : "başlangıç",
    "to" : "bitiş",
    "This event's repeating rule is not supported yet." : "Bu etkinliğin yinelenme kuralı henüz desteklenmiyor.",
    "Support for advanced rules will be added with subsequent updates." : "Gelişmiş kural desteği sonraki sürümlerde eklenecek.",
    "Reset repeating rule" : "Yinelenme kuralını sıfırla",
    "Repeat every ..." : "Yinelenme...",
    "end repeat ..." : "yinelenme sonu...",
    "times" : "kez",
    "Import Calendars" : "Takvimleri Al",
    "Import canceled" : "Alma işlemi iptal edildi",
    "Analyzing calendar" : "Takvim inceleniyor",
    "The file contains objects incompatible with the selected calendar" : "Dosyada, seçilmiş takvime uygun olmayan nesneler var",
    "New calendar" : "Takvim ekle",
    "File is empty" : "Dosya boş",
    "Import scheduled" : "Alma işlemi zamanlandı",
    "Subscribe & embed" : "Abone ol ve yerleştir",
    "Publish URL" : "Yayın adresi",
    "Iframe to integrate" : "bütünleştirilecek Iframe",
    "Settings & import" : "Ayarlar ve Alma",
    "Skip simple event editor" : "Basit etkinlik düzenleyici atlansın",
    "Show week numbers" : "Hafta numaraları görüntülensin",
    "Import calendar" : "Takvimi al",
    "No Calendars selected for import" : "Alınacak bir takvim seçilmemiş",
    "Primary CalDAV address" : "Birincil CalDAV adresi",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresi"
},
"nplurals=2; plural=(n > 1);");
